/* A representation of the items in the ignore file. This file should
* start and end with '<Ignore>' and '</Ignore>' and in between these
* tags should contain a list of entries of the format
* '<Property>...</Property>', '<Title>...</Title>', and
* '<Class>...</Class>'. These give, respectively, the set of component
* property names, component titles, and component classes to ignore
* when doing the comparison.
*/

package oracle; 

import java.io.*; 
import org.jdom.*; 
import org.jdom.input.*; 
import java.util.*; 

public class Ignore {

    /* Set of component property names to ignore when doing the
     * comparison.
     */
    private HashSet<String> properties; 

    /* Set of component titles to ignore when doing the comparison.
     */
    private HashSet<String> titles; 

    /* Set of component classes to ignore when doing the comparison.
     */
    private HashSet<String> classes; 

    /* Set of properties that cannot be ignored. 
     */
    private static final String[] UNIGNORABLE_ARR = {"Title", "Class"}; 
    private static final HashSet<String> UNIGNORABLE = new HashSet<String>(Arrays.asList(UNIGNORABLE_ARR)); 

    public Ignore(File f) throws IOException, JDOMException {
	properties = new HashSet<String>(); 
	titles = new HashSet<String>(); 
	classes = new HashSet<String>(); 
	if (f != null) {
	    SAXBuilder parser = new SAXBuilder();
	    Document doc = parser.build(f);
	    Element root = doc.getRootElement(); 
	    for (Object o : root.getChildren()) {
		Element e = (Element) o; 
		if (e.getName().equals("Property")) {
		    if (UNIGNORABLE.contains(e.getText())) {
			System.err.println("WARNING: Skipping unignorable property " + e.getText() + " in " + f.getPath()); 
		    } else {
			properties.add(e.getText()); 
		    }
		} else if (e.getName().equals("Title")) {
		    titles.add(e.getText()); 
		} else if (e.getName().equals("Class")) {
		    classes.add(e.getText()); 
		} else {
		    System.err.println("WARNING: Skipping unknown element " + e.getName() + " in " + f.getPath()); 
		}
	    }
	}
    }

    public HashSet<String> getProperties() {
	return properties; 
    }

    public HashSet<String> getTitles() {
	return titles; 
    }
    
    public HashSet<String> getClasses() {
	return classes; 
    }

}

